package com.ruoyi.project.ehs.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.ehs.mapper.TAutosprinklerMapper;
import com.ruoyi.project.ehs.domain.TAutosprinkler;
import com.ruoyi.project.ehs.service.ITAutosprinklerService;

import javax.annotation.Resource;

/**
 * 自动喷淋系统Service业务层处理
 *
 * @author ruoyi
 * @date 2020-11-25
 */
@Service
public class TAutosprinklerServiceImpl implements ITAutosprinklerService
{
    @Resource
    private TAutosprinklerMapper tAutosprinklerMapper;

    /**
     * 查询自动喷淋系统
     *
     * @param id 自动喷淋系统ID
     * @return 自动喷淋系统
     */
    @Override
    public TAutosprinkler selectTAutosprinklerById(Long id)
    {
        return tAutosprinklerMapper.selectTAutosprinklerById(id);
    }

    /**
     * 查询自动喷淋系统列表
     *
     * @param tAutosprinkler 自动喷淋系统
     * @return 自动喷淋系统
     */
    @Override
    public List<TAutosprinkler> selectTAutosprinklerList(TAutosprinkler tAutosprinkler)
    {
        return tAutosprinklerMapper.selectTAutosprinklerList(tAutosprinkler);
    }

    /**
     * 定时任务查询自动喷淋系统列表
     *
     * @param tAutosprinkler 自动喷淋系统
     * @return 自动喷淋系统集合
     */
    @Override
    public List<TAutosprinkler> selectList(TAutosprinkler tAutosprinkler) {
        return tAutosprinklerMapper.selectList(tAutosprinkler);
    }

    /**
     * 新增自动喷淋系统
     *
     * @param tAutosprinkler 自动喷淋系统
     * @return 结果
     */
    @Override
    public int insertTAutosprinkler(TAutosprinkler tAutosprinkler)
    {
        return tAutosprinklerMapper.insertTAutosprinkler(tAutosprinkler);
    }

    /**
     * 修改自动喷淋系统
     *
     * @param tAutosprinkler 自动喷淋系统
     * @return 结果
     */
    @Override
    public int updateTAutosprinkler(TAutosprinkler tAutosprinkler)
    {
        return tAutosprinklerMapper.updateTAutosprinkler(tAutosprinkler);
    }

    /**
     * 批量删除自动喷淋系统
     *
     * @param ids 需要删除的自动喷淋系统ID
     * @return 结果
     */
    @Override
    public int deleteTAutosprinklerByIds(Long[] ids)
    {
        return tAutosprinklerMapper.deleteTAutosprinklerByIds(ids);
    }

    /**
     * 删除自动喷淋系统信息
     *
     * @param id 自动喷淋系统ID
     * @return 结果
     */
    @Override
    public int deleteTAutosprinklerById(Long id)
    {
        return tAutosprinklerMapper.deleteTAutosprinklerById(id);
    }
}
